@@ -24,8 +24,20 @@ class TestCliConfig:
     @pytest.mark.parametrize("flag,attr", [
         ("--enable-debug", "enable_debug"),
         ("--disable-blocking", "disable_blocking"),
-        ("--allow-unverified", "allow_unverified")
+        ("--allow-unverified", "allow_unverified"),
+        ("--enable-diff", "enable_diff")
     ])
     def test_boolean_flags(self, flag, attr):
         config = CliConfig.from_args(["--api-token", "test", flag])
-        assert getattr(config, attr) is True
\ No newline at end of file
+        assert getattr(config, attr) is True
+
+    def test_enable_diff_default_false(self):
+        """Test that enable_diff defaults to False"""
+        config = CliConfig.from_args(["--api-token", "test"])
+        assert config.enable_diff is False
+
+    def test_enable_diff_with_integration_api(self):
+        """Test that enable_diff can be used with integration api"""
+        config = CliConfig.from_args(["--api-token", "test", "--integration", "api", "--enable-diff"])
+        assert config.enable_diff is True
+        assert config.integration_type == "api"
\ No newline at end of file
